==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/et_EE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Reegli lühikirjeldus",
    "Add rule" : "Lisa reegel",
    "Reset" : "Lähtesta",
    "Save" : "Salvesta",
    "Saving…" : "Salvestamine...",
    "Saved" : "Salvestatud",
    "Saving failed:" : "Salvestamine ebaõnnestus:",
    "Add rule group" : "Lisa reegligrupp",
    "File MIME type" : "Faili MIME tüüp",
    "is" : "on",
    "is not" : "ei ole",
    "matches" : "kattub",
    "does not match" : "ei kattu",
    "Example: {placeholder}" : "Näide: {placeholder}",
    "File size (upload)" : "Faili suurus (üleslaadimine)",
    "less" : "väiksem",
    "less or equals" : "väiksem või võrdne",
    "greater or equals" : "suurem või võrdne",
    "greater" : "suurem",
    "File system tag" : "Faili süsteemi silt",
    "is tagged with" : "on sildiga",
    "is not tagged with" : "ei ole sildiga",
    "Select tag…" : "Vali silt...",
    "Request remote address" : "Päringu kaugaadress",
    "matches IPv4" : "kattub IPv4 aadressiga",
    "does not match IPv4" : "Ei kattu IPv4 aadressiga",
    "matches IPv6" : "kattub IPv6 aadressiga",
    "does not match IPv6" : "Ei kattu IPv6 aadressiga",
    "Request time" : "Päringu aeg",
    "between" : "vahemikus",
    "not between" : "ei ole vahemikus",
    "Start" : "Algus",
    "End" : "Lõpp",
    "Select timezone…" : "Vali ajavöönd",
    "Request URL" : "Päringu URL",
    "Predefined URLs" : "Eelmääratletud URL-id",
    "Files WebDAV" : "WebDAV failid",
    "Request user agent" : "Päringu \"user agent\"",
    "Sync clients" : "Kliendiprogrammid",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Töölaua klient",
    "User group membership" : "Kasutajagrupi liige",
    "is member of" : "on liige",
    "is not member of" : "ei ole liige",
    "The given regular expression is invalid" : "Antud regulaaravaldis on vigane",
    "The given file size is invalid" : "Antud faili suurus on vigane",
    "The given tag id is invalid" : "Antud sildi ID on vigane",
    "The given IP range is invalid" : "Antud IP vahemik on vigane",
    "The given IP range is not valid for IPv4" : "Antud IP vahemik ei kehti IPv4 kohta",
    "The given IP range is not valid for IPv6" : "Antud IP vahemik ei kehti IPv6 kohta",
    "The given time span is invalid" : "Antud ajavahemik on vigane",
    "The given start time is invalid" : "Antud algusaeg on vigane",
    "The given end time is invalid" : "Antud lõppaeg on vigane",
    "The given group does not exist" : "Antud gruppi ei leitud",
    "Operation #%s does not exist" : "Tegevus # %s ei leitud",
    "Operation %s does not exist" : "Tegevust %s ei leitud",
    "Operation %s is invalid" : "Tegevus %s on vigane",
    "Workflow" : "Töövoog",
    "Open documentation" : "Ava dokumentatsioon",
    "Loading…" : "Laadimine..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/et_EE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Reegli lühikirjeldus",
    "Add rule" : "Lisa reegel",
    "Reset" : "Lähtesta",
    "Save" : "Salvesta",
    "Saving…" : "Salvestamine...",
    "Saved" : "Salvestatud",
    "Saving failed:" : "Salvestamine ebaõnnestus:",
    "Add rule group" : "Lisa reegligrupp",
    "File MIME type" : "Faili MIME tüüp",
    "is" : "on",
    "is not" : "ei ole",
    "matches" : "kattub",
    "does not match" : "ei kattu",
    "Example: {placeholder}" : "Näide: {placeholder}",
    "File size (upload)" : "Faili suurus (üleslaadimine)",
    "less" : "väiksem",
    "less or equals" : "väiksem või võrdne",
    "greater or equals" : "suurem või võrdne",
    "greater" : "suurem",
    "File system tag" : "Faili süsteemi silt",
    "is tagged with" : "on sildiga",
    "is not tagged with" : "ei ole sildiga",
    "Select tag…" : "Vali silt...",
    "Request remote address" : "Päringu kaugaadress",
    "matches IPv4" : "kattub IPv4 aadressiga",
    "does not match IPv4" : "Ei kattu IPv4 aadressiga",
    "matches IPv6" : "kattub IPv6 aadressiga",
    "does not match IPv6" : "Ei kattu IPv6 aadressiga",
    "Request time" : "Päringu aeg",
    "between" : "vahemikus",
    "not between" : "ei ole vahemikus",
    "Start" : "Algus",
    "End" : "Lõpp",
    "Select timezone…" : "Vali ajavöönd",
    "Request URL" : "Päringu URL",
    "Predefined URLs" : "Eelmääratletud URL-id",
    "Files WebDAV" : "WebDAV failid",
    "Request user agent" : "Päringu \"user agent\"",
    "Sync clients" : "Kliendiprogrammid",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Töölaua klient",
    "User group membership" : "Kasutajagrupi liige",
    "is member of" : "on liige",
    "is not member of" : "ei ole liige",
    "The given regular expression is invalid" : "Antud regulaaravaldis on vigane",
    "The given file size is invalid" : "Antud faili suurus on vigane",
    "The given tag id is invalid" : "Antud sildi ID on vigane",
    "The given IP range is invalid" : "Antud IP vahemik on vigane",
    "The given IP range is not valid for IPv4" : "Antud IP vahemik ei kehti IPv4 kohta",
    "The given IP range is not valid for IPv6" : "Antud IP vahemik ei kehti IPv6 kohta",
    "The given time span is invalid" : "Antud ajavahemik on vigane",
    "The given start time is invalid" : "Antud algusaeg on vigane",
    "The given end time is invalid" : "Antud lõppaeg on vigane",
    "The given group does not exist" : "Antud gruppi ei leitud",
    "Operation #%s does not exist" : "Tegevus # %s ei leitud",
    "Operation %s does not exist" : "Tegevust %s ei leitud",
    "Operation %s is invalid" : "Tegevus %s on vigane",
    "Open documentation" : "Ava dokumentatsioon",
    "Loading…" : "Laadimine...",
    "Workflow" : "Töövoog"
},
"nplurals=2; plural=(n != 1);");
